# antiope-aws
Python module & scripts for managing Multiple AWS accounts leveraging Antiope

## Rationale




## Installation

For testing, the install process is
```bash
pip install -e .
```

For production usage, you can install antiope-aws from PyPi.

## Usage

### Manifest Files

### Scripts

None yet


### Python Module

The Python Modules consists of three main classes.

All modules use the python logger for debug and informational events. These can be overridden as needed.

#### AWSAccount

#### ForeignAWSAccount

#### AWSOrganization

#### VPC



## Roadmap



